@@ -29,7 +29,7 @@ class BuildHookBase(BuildHookInterface):
                 file.flush()
 
                 self.__files.append(file)
-                build_data['force_include'][str(distribution_path.with_suffix('.mo'))] = file.name
+                build_data['force_include'][file.name] = str(distribution_path.with_suffix('.mo'))
                 print(f'doing {path}')
 
         if 'exclude' not in build_data:
