@@ -7,5 +7,8 @@ class MsgfmtPyBuildHook(BuildHookBase):
 
     @staticmethod
     def convert(input: Path) -> bytes:
+        print(f'converting {input}')
+        with input.open('r') as file:
+            print(f'{file.read()=}')
         with input.open('rb') as file:
             return make(file)
